==> PhpGedView-basic-4.2.zip: themes/ocean/toplinks.php <==
<?php
/**
 * Top-of-page menu for Ocean theme
 *
 * PhpGedView: Genealogy Viewer
 * Copyright (c) 2002 to 2008  John Finlay and others.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @package PhpGedView
 * @subpackage Themes
 * @version $Id: toplinks.php 4487 2008-12-10 10:01:50Z fisharebest $
 */

if (!defined('PGV_PHPGEDVIEW')) {
	header('HTTP/1.0 403 Forbidden');
	exit;
}

$menubar = new MenuBar();
?>
<tr>
	<td>
		<div align="center">
			<table width="100%">
				<tr>
					<?php
					$menu = $menubar->getGedcomMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getMygedviewMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getChartsMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getListsMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getCalendarMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getReportsMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getClippingsMenu();
					if((!is_null($menu)) && ($menu->link != "")) {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getSearchMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getOptionalMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menus = $menubar->getModuleMenus();
					foreach($menus as $m=>$menu) {
						if($menu->link != "") {
							print "\t<td width=\"7%\" valign=\"top\">\n";
							$menu->printMenu();
							print "\t</td>\n";
						}
					}
					$menu = $menubar->getHelpMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					?>
				</tr>
			</table>
		</div>
	</td>
</tr>
</table>
<br />
<?php require './includes/accesskeyHeaders.php'; ?>
</div>
<!-- close div for div id="header" -->
<?php print "<div id=\"content\">\n"; ?>
<a name="content"></a>

==> PhpGedView-basic-4.2.3.zip: themes/ocean/toplinks.php <==
<?php
/**
 * Top-of-page menu for Ocean theme
 *
 * PhpGedView: Genealogy Viewer
 * Copyright (c) 2002 to 2008  John Finlay and others.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @package PhpGedView
 * @subpackage Themes
 * @version $Id: toplinks.php 6481 2009-11-28 20:17:25Z fisharebest $
 */

if (!defined('PGV_PHPGEDVIEW')) {
	header('HTTP/1.0 403 Forbidden');
	exit;
}

$menubar = new MenuBar();
?>
<tr>
	<td>
		<div align="center">
			<table width="100%">
				<tr>
					<?php
					$menu = $menubar->getGedcomMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getMygedviewMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getChartsMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getListsMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getCalendarMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getReportsMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getClippingsMenu();
					if((!is_null($menu)) && ($menu->link != "")) {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getSearchMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menu = $menubar->getOptionalMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					$menus = $menubar->getModuleMenus();
					foreach($menus as $m=>$menu) {
						if($menu->link != "") {
							print "\t<td width=\"7%\" valign=\"top\">\n";
							$menu->printMenu();
							print "\t</td>\n";
						}
					}
					$menu = $menubar->getHelpMenu();
					if($menu->link != "") {
						print "\t<td width=\"7%\" valign=\"top\">\n";
						$menu->printMenu();
						print "\t</td>\n";
					}
					?>
				</tr>
			</table>
		</div>
	</td>
</tr>
</table>
<br />
<?php require PGV_ROOT.'includes/accesskeyHeaders.php'; ?>
</div>
<!-- close div for div id="header" -->
<?php print "<div id=\"content\">\n"; ?>
<a name="content"></a>
